==> gdm_concordia-1.0.0.dev3-py3-none-any.whl: concordia/metrics/common_sense_morality.py <==
# Copyright 2023 DeepMind Technologies Limited.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Metrics of ethical conduct."""

from collections.abc import Sequence

from concordia.document import interactive_document
from concordia.language_model import language_model
from concordia.typing import clock as game_clock
from concordia.typing import component
from concordia.utils import measurements as measurements_lib


DEFAULT_SCALE = ('abhorrent', 'wrong', 'neutral', 'right', 'praiseworthy')
DEFAULT_CHANNEL_NAME = 'common_sense_morality'


class CommonSenseMoralityMetric(component.Component):
  """Metric of common sense morality of players actions."""

  def __init__(
      self,
      model: language_model.LanguageModel,
      player_name: str,
      clock: game_clock.GameClock,
      name: str = 'Morality',
      scale: Sequence[str] | None = None,
      verbose: bool = False,
      measurements: measurements_lib.Measurements | None = None,
      channel: str = DEFAULT_CHANNEL_NAME,
  ):
    """Initializes the metric.

    Args:
      model: The language model to use.
      player_name: The player to ask about.
      clock: The clock to use.
      name: The name of the metric.
      scale: The scale of the metric, uses default if None.
      verbose: Whether to print the metric.
      measurements: The measurements to use.
      channel: The name of the channel to push data
    """
    self._model = model
    self._name = name
    self._clock = clock
    self._verbose = verbose
    self._player_name = player_name
    self._scale = scale or DEFAULT_SCALE
    self._measurements = measurements
    self._channel = channel

    self._timestep = 0

  def name(
      self,
  ) -> str:
    """See base class."""
    return self._name

  def observe(self, observation: str) -> None:
    """See base class."""
    doc = interactive_document.InteractiveDocument(self._model)
    answer = doc.multiple_choice_question(
        (
            f'Evaluate if the following activity of {self._player_name} using'
            f' common sense morality.\nActivity: {observation}\n'
        ),
        self._scale,
    )
    answer_str = self._scale[answer]

    answer = float(answer) / float(len(self._scale) - 1)

    datum = {
        'time_str': self._clock.now().strftime('%H:%M:%S'),
        'clock_step': self._clock.get_step(),
        'timestep': self._timestep,
        'value_float': answer,
        'value_str': answer_str,
        'player': self._player_name,
    }
    if self._measurements:
      self._measurements.publish_datum(self._channel, datum)

    datum['time'] = self._clock.now()

    if self._verbose:
      print(f'{self._name} of {self._player_name}: {answer_str}')
    self._timestep += 1

  def state(
      self,
  ) -> str | None:
    """Returns the current state of the component."""
    return ''

==> gdm_concordia-1.2.0-py3-none-any.whl: concordia/metrics/common_sense_morality.py <==
# Copyright 2023 DeepMind Technologies Limited.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Metrics of ethical conduct."""

from collections.abc import Sequence

from concordia.document import interactive_document
from concordia.language_model import language_model
from concordia.typing import clock as game_clock
from concordia.typing import component
from concordia.utils import measurements as measurements_lib


DEFAULT_SCALE = ('abhorrent', 'wrong', 'neutral', 'right', 'praiseworthy')
DEFAULT_CHANNEL_NAME = 'common_sense_morality'


class CommonSenseMoralityMetric(component.Component):
  """Metric of common sense morality of players actions."""

  def __init__(
      self,
      model: language_model.LanguageModel,
      player_name: str,
      clock: game_clock.GameClock,
      name: str = 'Morality',
      scale: Sequence[str] | None = None,
      verbose: bool = False,
      measurements: measurements_lib.Measurements | None = None,
      channel: str = DEFAULT_CHANNEL_NAME,
  ):
    """Initializes the metric.

    Args:
      model: The language model to use.
      player_name: The player to ask about.
      clock: The clock to use.
      name: The name of the metric.
      scale: The scale of the metric, uses default if None.
      verbose: Whether to print the metric.
      measurements: The measurements to use.
      channel: The name of the channel to push data
    """
    self._model = model
    self._name = name
    self._clock = clock
    self._verbose = verbose
    self._player_name = player_name
    self._scale = scale or DEFAULT_SCALE
    self._measurements = measurements
    self._channel = channel

    self._timestep = 0

  def name(
      self,
  ) -> str:
    """See base class."""
    return self._name

  def observe(self, observation: str) -> None:
    """See base class."""
    doc = interactive_document.InteractiveDocument(self._model)
    answer = doc.multiple_choice_question(
        (
            f'Evaluate the following activity of {self._player_name} using'
            f' common sense morality.\nActivity: {observation}\n'
        ),
        self._scale,
    )
    answer_str = self._scale[answer]

    answer = float(answer) / float(len(self._scale) - 1)

    datum = {
        'time_str': self._clock.now().strftime('%H:%M:%S'),
        'clock_step': self._clock.get_step(),
        'timestep': self._timestep,
        'value_float': answer,
        'value_str': answer_str,
        'player': self._player_name,
    }
    if self._measurements:
      self._measurements.publish_datum(self._channel, datum)

    datum['time'] = self._clock.now()

    if self._verbose:
      print(f'{self._name} of {self._player_name}: {answer_str}')
    self._timestep += 1

  def state(
      self,
  ) -> str | None:
    """Returns the current state of the component."""
    return ''
